==> openstack4j-2.11-sources.jar: org/openstack4j/core/transport/UntrustedSSL.java <==
package org.openstack4j.core.transport;

import java.security.SecureRandom;
import java.security.cert.X509Certificate;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;

import org.openstack4j.openstack.logging.Logger;
import org.openstack4j.openstack.logging.LoggerFactory;

/**
 * Contains an open SSL Context which allows self signed certs and an open hostname verifier
 * 
 * @author Jeremy Unruh
 */
public class UntrustedSSL {

    private static final UntrustedSSL INSTANCE = new UntrustedSSL();
    private static final Logger LOG = LoggerFactory.getLogger(UntrustedSSL.class);

    private SSLContext context;
    private HostnameVerifier verifier;
    
    private UntrustedSSL() {
        try
        {
            TrustManager[] trustAllCerts = new TrustManager[] { new X509TrustManager() {
                public X509Certificate[] getAcceptedIssuers() {
                    return null;
                }
                public void checkClientTrusted(X509Certificate[] certs, String authType) {}
                public void checkServerTrusted(X509Certificate[] certs, String authType) {}
            } };
            SSLContext ssc = SSLContext.getInstance("TLS");
            ssc.init(null, trustAllCerts, new SecureRandom());

            this.context = ssc;
            this.verifier = new HostnameVerifier() {
                @Override
                public boolean verify(String s, SSLSession session) {
                    return true;
                } };
        }
        catch (Throwable t) {
            LOG.error(t.getMessage(), t);
        }
    }
    
    public static SSLContext getSSLContext() {
        return INSTANCE.context;
    }
    
    public static HostnameVerifier getHostnameVerifier() {
        return INSTANCE.verifier;
    }
    
}

==> openstack4j-3.0.4-sources.jar: org/openstack4j/core/transport/UntrustedSSL.java <==
package org.openstack4j.core.transport;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.net.ssl.*;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;

/**
 * Contains an open SSL Context which allows self signed certs and an open hostname verifier
 *
 * @author Jeremy Unruh
 */
public class UntrustedSSL {

    private static final UntrustedSSL INSTANCE = new UntrustedSSL();
    private static final Logger LOG = LoggerFactory.getLogger(UntrustedSSL.class);

    private SSLContext context;
    private HostnameVerifier verifier;

    private UntrustedSSL() {
        try
        {
            TrustManager[] trustAllCerts = new TrustManager[] { new X509TrustManager() {
                public X509Certificate[] getAcceptedIssuers() {
                    return null;
                }
                public void checkClientTrusted(X509Certificate[] certs, String authType) {}
                public void checkServerTrusted(X509Certificate[] certs, String authType) {}
            } };
            SSLContext ssc = SSLContext.getInstance("TLS");
            ssc.init(null, trustAllCerts, new SecureRandom());

            this.context = ssc;
            this.verifier = new HostnameVerifier() {
                @Override
                public boolean verify(String s, SSLSession session) {
                    return true;
                } };
        }
        catch (Throwable t) {
            LOG.error(t.getMessage(), t);
        }
    }

    public static SSLContext getSSLContext() {
        return INSTANCE.context;
    }

    public static HostnameVerifier getHostnameVerifier() {
        return INSTANCE.verifier;
    }

}
